@@ -27,7 +27,7 @@ Benchmark::Timer - Benchmarking with statistical confidence
       &long_running_operation();
       $t->stop('tag');
   }
-  print $t->get_report;
+  print $t->report;
 
   # --------------------------------------------------------------------
 
@@ -40,7 +40,7 @@ Benchmark::Timer - Benchmarking with statistical confidence
       &long_running_operation();
       $t->stop('tag');
   }
-  print $t->get_report;
+  print $t->report;
 
 =head1 DESCRIPTION
 
@@ -50,25 +50,27 @@ trials. It is perfect for when you need more precise information about the
 running time of portions of your code than the Benchmark module will give
 you, but don't want to go all out and profile your code.
 
-The methodology is simple; create a Benchmark::Timer object, and wrap
-portions of code that you want to benchmark with C<start()> and C<stop()>
-method calls. You supply a unique tag, or event name, to those methods.
-This allows one Benchmark::Timer object to benchmark many pieces of code.
-If you provide error and confidence values, you can also use
+The methodology is simple; create a Benchmark::Timer object, and wrap portions
+of code that you want to benchmark with C<start()> and C<stop()> method calls.
+You can supply a tag to those methods if you plan to time multiple portions of
+code.  If you provide error and confidence values, you can also use
 C<need_more_samples()> to determine, statistically, whether you need to
 collect more data.
 
-When you have run your code (one time or over multiple trials), you can
-obtain information about the running time by calling the C<results()>
-method or get a descriptive benchmark report by calling C<get_report()>.
-
-If you run your code over multiple trials, the average time is reported.
-This is wonderful for benchmarking time-critical portions of code in a
-rigorous way. You can also optionally choose to skip any number of initial
-trials to cut down on initial case irregularities.
+After you have run your code, you can obtain information about the running
+time by calling the C<results()> method, or get a descriptive benchmark report
+by calling C<report()>.  If you run your code over multiple trials, the
+average time is reported.  This is wonderful for benchmarking time-critical
+portions of code in a rigorous way. You can also optionally choose to skip any
+number of initial trials to cut down on initial case irregularities.
 
 =head1 METHODS
 
+In all of the following methods, C<$tag> refers to the user-supplied name of
+the code being timed. Unless otherwise specified, $tag defaults to the tag of
+the last call to C<start()>, or "_default" if C<start()> was not previously
+called with a tag.
+
 =over 4
 
 =cut
@@ -85,12 +87,12 @@ use Carp;
 use Time::HiRes qw( gettimeofday tv_interval );
 
 use vars qw($VERSION);
-$VERSION = '0.6.1';
+$VERSION = '0.7.0';
 
 use constant BEFORE     => 0;
 use constant ELAPSED    => 1;
-use constant LASTEVENT  => 2;
-use constant EVENTS     => 3;
+use constant LASTTAG    => 2;
+use constant TAGS       => 3;
 use constant SKIP       => 4;
 use constant MINIMUM    => 5;
 use constant SKIPCOUNT  => 6;
@@ -155,7 +157,7 @@ sub new {
 =item $t->reset;
 
 Reset the timer object to the pristine state it started in.
-Erase all memory of events and any previously accumulated timings.
+Erase all memory of tags and any previously accumulated timings.
 Returns a reference to the timer object. It takes the same arguments
 the constructor takes.
 
@@ -167,10 +169,10 @@ sub reset {
 
     $self->[BEFORE] = {};          # [ gettimeofday ] storage
     $self->[ELAPSED] = {};         # elapsed fractional seconds
-    $self->[LASTEVENT] = undef;    # what the last event was
-    $self->[EVENTS] = [];          # keep list of events in order seen
-    $self->[SKIP] = 0;             # how many events to skip
-    $self->[MINIMUM] = 1;          # how many events to skip
+    $self->[LASTTAG] = undef;      # what the last tag was
+    $self->[TAGS] = [];            # keep list of tags in order seen
+    $self->[SKIP] = 0;             # how many samples to skip
+    $self->[MINIMUM] = 1;          # the minimum number of trails to run
     $self->[SKIPCOUNT] = {};       # trial skip storage
     delete $self->[CONFIDENCE];    # confidence factor
     delete $self->[ERROR];         # allowable error
@@ -238,11 +240,8 @@ sub reset {
 
 =item $t->start($tag);
 
-Record the current time so that when C<stop()> is called, we can calculate
-an elapsed time. Supply a $tag which is simply a string that is the
-descriptive name of the event you are timing. If you do not supply a
-$tag, the last event tag is used; if there is none, a "_default" tag
-is used instead.
+Record the current time so that when C<stop()> is called, we can calculate an
+elapsed time. 
 
 =cut
 
@@ -251,23 +250,23 @@ is used instead.
 
 sub start {
     my $self = shift;
-    my $event = shift || $self->[LASTEVENT] || '_default';
-    $self->[LASTEVENT] = $event;
-    if(exists $self->[SKIPCOUNT]->{$event}) {
-        if($self->[SKIPCOUNT]->{$event} > 1) {
-            $self->[SKIPCOUNT]->{$event}--;
+    my $tag = shift || $self->[LASTTAG] || '_default';
+    $self->[LASTTAG] = $tag;
+    if(exists $self->[SKIPCOUNT]->{$tag}) {
+        if($self->[SKIPCOUNT]->{$tag} > 1) {
+            $self->[SKIPCOUNT]->{$tag}--;
         } else {
-            $self->[SKIPCOUNT]->{$event} = 0;
-            push @{$self->[BEFORE]->{$event}}, [ gettimeofday ];
+            $self->[SKIPCOUNT]->{$tag} = 0;
+            push @{$self->[BEFORE]->{$tag}}, [ gettimeofday ];
         }
     } else {
-        push @{$self->[EVENTS]}, $event;
-        $self->[SKIPCOUNT]->{$event} = $self->[SKIP] + 1;
-        if($self->[SKIPCOUNT]->{$event} > 1) {
-            $self->[SKIPCOUNT]->{$event}--;
+        push @{$self->[TAGS]}, $tag;
+        $self->[SKIPCOUNT]->{$tag} = $self->[SKIP] + 1;
+        if($self->[SKIPCOUNT]->{$tag} > 1) {
+            $self->[SKIPCOUNT]->{$tag}--;
         } else {
-            $self->[SKIPCOUNT]->{$event} = 0;
-            $self->[BEFORE]->{$event} = [ [ gettimeofday ] ]
+            $self->[SKIPCOUNT]->{$tag} = 0;
+            $self->[BEFORE]->{$tag} = [ [ gettimeofday ] ]
         }
     }
 }
@@ -275,47 +274,45 @@ sub start {
 
 =item $t->stop($tag);
 
-Record timing information. The optional $tag is the event for which you
-are timing, and defaults to the $tag supplied to the last C<start()> call.
-If a $tag is supplied, it must correspond to one given to a previously
-called C<start()> call. It returns the elapsed time in milliseconds.
-C<stop()> throws an exception if the timer gets out of sync (e.g. the
-number of C<start()>s does not match the number of C<stop()>s.)
+Record timing information. If $tag is supplied, it must correspond to one
+given to a previously called C<start()> call. It returns the elapsed time in
+milliseconds.  C<stop()> croaks if the timer gets out of sync (e.g. the number
+of C<start()>s does not match the number of C<stop()>s.)
 
 =cut
 
 sub stop {
     my $after = [ gettimeofday ];    # minimize overhead
     my $self = shift;
-    my $event = shift || $self->[LASTEVENT] || '_default';
+    my $tag = shift || $self->[LASTTAG] || '_default';
 
-    croak 'must call $t->start($event) before $t->stop($event)'
-        unless exists $self->[SKIPCOUNT]->{$event};
+    croak 'must call $t->start($tag) before $t->stop($tag)'
+        unless exists $self->[SKIPCOUNT]->{$tag};
 
-    return if $self->[SKIPCOUNT]->{$event} > 0;
+    return if $self->[SKIPCOUNT]->{$tag} > 0;
 
-    my $i = exists $self->[ELAPSED]->{$event} ?
-        scalar @{$self->[ELAPSED]->{$event}} : 0;
-    my $before = $self->[BEFORE]->{$event}->[$i];
+    my $i = exists $self->[ELAPSED]->{$tag} ?
+        scalar @{$self->[ELAPSED]->{$tag}} : 0;
+    my $before = $self->[BEFORE]->{$tag}->[$i];
     croak 'timer out of sync' unless defined $before;
 
     # Create a stats object if we need to
-    if (defined $self->[CONFIDENCE] && !defined $self->[STAT]->{$event})
+    if (defined $self->[CONFIDENCE] && !defined $self->[STAT]->{$tag})
     {
-      $self->[STAT]->{$event} = Statistics::PointEstimation->new;
-      $self->[STAT]->{$event}->set_significance($self->[CONFIDENCE]);
+      $self->[STAT]->{$tag} = Statistics::PointEstimation->new;
+      $self->[STAT]->{$tag}->set_significance($self->[CONFIDENCE]);
     }
 
     my $elapsed = tv_interval($before, $after);
 
     if($i > 0) {
-        push @{$self->[ELAPSED]->{$event}}, $elapsed;
+        push @{$self->[ELAPSED]->{$tag}}, $elapsed;
     } else {
-        $self->[ELAPSED]->{$event} = [ $elapsed ];
+        $self->[ELAPSED]->{$tag} = [ $elapsed ];
     }
 
-    $self->[STAT]->{$event}->add_data($elapsed)
-      if defined $self->[STAT]->{$event};
+    $self->[STAT]->{$tag}->add_data($elapsed)
+      if defined $self->[STAT]->{$tag};
 
     return $elapsed;
 }
@@ -324,11 +321,9 @@ sub stop {
 =item $t->need_more_samples($tag);
 
 Compute the estimated error in the average of the data collected thus far, and
-return true if that error exceeds the user-specified error.  The optional $tag
-is the event for which you are timing, and defaults to the $tag supplied to
-the last C<start()> call or the default tag if C<start()> has not yet been
-called.  If a $tag is supplied, it must correspond to one given to a
-previously called C<start()> call. 
+return true if that error exceeds the user-specified error. If a $tag is
+supplied, it must correspond to one given to a previously called C<start()>
+call. 
 
 This routine assumes that the data are normally distributed.
 
@@ -336,89 +331,122 @@ This routine assumes that the data are normally distributed.
 
 sub need_more_samples {
     my $self = shift;
-    my $event = shift || $self->[LASTEVENT] || '_default';
+    my $tag = shift || $self->[LASTTAG] || '_default';
 
     carp 'You must set the confidence and error in order to use need_more_samples'
       unless defined $self->[CONFIDENCE];
 
     # In case this function is called before any trials are run
     return 1
-      if !defined $self->[STAT]->{$event} ||
-      $self->[STAT]->{$event}->count < $self->[MINIMUM];
+      if !defined $self->[STAT]->{$tag} ||
+      $self->[STAT]->{$tag}->count < $self->[MINIMUM];
 
     # For debugging
 #    printf STDERR "Average: %.5f +/- %.5f, Samples: %d\n",
-#      $self->[STAT]->{$event}->mean(), $self->[STAT]->{$event}->delta(),
-#      $self->[STAT]->{$event}->count;
+#      $self->[STAT]->{$tag}->mean(), $self->[STAT]->{$tag}->delta(),
+#      $self->[STAT]->{$tag}->count;
 #    printf STDERR "Percent Error: %.5f > %.5f\n",
-#      $self->[STAT]->{$event}->delta() / $self->[STAT]->{$event}->mean() * 100,
+#      $self->[STAT]->{$tag}->delta() / $self->[STAT]->{$tag}->mean() * 100,
 #      $self->[ERROR];
 
-    return (($self->[STAT]->{$event}->delta() / $self->[STAT]->{$event}->mean() * 100) >
+    return (($self->[STAT]->{$tag}->delta() / $self->[STAT]->{$tag}->mean() * 100) >
       $self->[ERROR]);
 }
 
 
-=item $t->get_report($tag);
+=item $t->report($tag);
 
-Get a simple report on the collected timings to STDERR, either for a single
-specified tag or all tags if none is specified. This report prints the number
-of trials run, the total time taken, and, if more than one trial was run, the
-average time needed to run one trial and error information. It prints the
-events out in the order they were C<start()>ed.
+Returns a string containing a simple report on the collected timings for $tag.
+This report contains the number of trials run, the total time taken, and, if
+more than one trial was run, the average time needed to run one trial and
+error information.  C<report()> will complain (via a warning) if a tag is
+still active.
 
 =cut
 
-sub get_report {
+sub report {
     my $self = shift;
-    my $event = shift || $self->[LASTEVENT] || undef;
+    my $tag = shift || $self->[LASTTAG] || '_default';
 
-    my $report = '';
+    unless(exists $self->[ELAPSED]->{$tag}) {
+        carp join ' ', 'tag', $tag, 'still running';
+        return;
+    }
 
-    if (defined $event)
-    {
-      $report = $self->_get_report($event);
-    }
-    else
-    {
-      foreach my $event (@{$self->[EVENTS]}) {
-        $report .= $self->_get_report($event);
-      }
-    }
-    return $report;
+    return $self->_report($tag);
 }
 
 
-sub _get_report {
-    my $self = shift;
-    my $event = shift;
+=item $t->reports;
 
-    unless(exists $self->[ELAPSED]->{$event}) {
-      return "Tag $event is still running or has not completed its skipped runs, skipping\n";
+In a scalar context, returns a string containing a simple report on the
+collected timings for all tags. The report is a concatenation of the
+individual tag reports, in the original tag order. In an list context, returns
+a hash keyed by tag and containing reports for each tag. The return value is
+actually an array, so that the original tag order is preserved if you assign
+to an array instead of a hash. C<reports()> will complain (via a warning) if a
+tag is still active.
+
+
+=cut
+
+sub reports {
+    my $self = shift;
+
+    if (wantarray)
+    {
+      my @reports;
+
+      foreach my $tag (@{$self->[TAGS]}) {
+          push @reports, $tag;
+          push @reports, $self->report($tag);
+      }
+
+      return @reports;
+    }
+    else
+    {
+      my $report = '';
+
+      foreach my $tag (@{$self->[TAGS]}) {
+        $report .= $self->report($tag);
+      }
+
+      return $report;
+    }
+}
+
+
+sub _report {
+    my $self = shift;
+    my $tag = shift;
+
+    unless(exists $self->[ELAPSED]->{$tag}) {
+      return "Tag $tag is still running or has not completed its skipped runs, skipping\n";
     }
 
     my $report = '';
 
-    my @times = @{$self->[ELAPSED]->{$event}};
+    my @times = @{$self->[ELAPSED]->{$tag}};
     my $n = scalar @times;
     my $total = 0; $total += $_ foreach @times;
 
     if ($n == 1)
     {
       $report .= sprintf "\%d trial of \%s (\%s total)\n",
-        $n, $event, timestr($total);
+        $n, $tag, timestr($total);
     }
     else
     {
       $report .= sprintf "\%d trials of \%s (\%s total), \%s/trial\n",
-        $n, $event, timestr($total), timestr($total / $n);
+        $n, $tag, timestr($total), timestr($total / $n);
     }
 
-    if (defined $self->[STAT]->{$event})
+    if (defined $self->[STAT]->{$tag})
     {
       my $delta = 0;
-      $delta = $self->[STAT]->{$event}->delta()
-        if defined $self->[STAT]->{$event}->delta();
+      $delta = $self->[STAT]->{$tag}->delta()
+        if defined $self->[STAT]->{$tag}->delta();
       
       $report .= sprintf "Error: +/- \%.5f with \%s confidence\n",
         $delta, $self->[CONFIDENCE];
@@ -428,22 +456,22 @@ sub _get_report {
 }
 
 
-=item $t->result($event);
+=item $t->result($tag);
 
-Return the time it took for $event to elapse, or the mean time it took for
-$event to elapse once, if $event happened more than once. C<result()>
-will complain (via a warning) if an event is still active.
+Return the time it took for $tag to elapse, or the mean time it took for $tag
+to elapse once, if $tag was used to time code more than once. C<result()> will
+complain (via a warning) if a tag is still active.
 
 =cut
 
 sub result {
     my $self = shift;
-    my $event = shift || $self->[LASTEVENT] || '_default';
-    unless(exists $self->[ELAPSED]->{$event}) {
-        carp join ' ', 'event', $event, 'still running';
+    my $tag = shift || $self->[LASTTAG] || '_default';
+    unless(exists $self->[ELAPSED]->{$tag}) {
+        carp join ' ', 'tag', $tag, 'still running';
         return;
     }
-    my @times = @{$self->[ELAPSED]->{$event}};
+    my @times = @{$self->[ELAPSED]->{$tag}};
     my $total = 0; $total += $_ foreach @times;
     return $total / @times;
 }
@@ -451,55 +479,55 @@ sub result {
 
 =item $t->results;
 
-Returns the timing data as a hash keyed on event tags where each value is
-the time it took to run that event, or the are the average time it took,
-if that event ran more than once. In scalar context it returns a reference
+Returns the timing data as a hash keyed on tags where each value is
+the time it took to run that code, or the average time it took,
+if that code ran more than once. In scalar context it returns a reference
 to that hash. The return value is actually an array, so that the original
-event order is preserved.
+tag order is preserved if you assign to an array instead of a hash.
 
 =cut
 
 sub results {
     my $self = shift;
     my @results;
-    foreach my $event (@{$self->[EVENTS]}) {
-        push @results, $event;
-        push @results, $self->result($event);
+    foreach my $tag (@{$self->[TAGS]}) {
+        push @results, $tag;
+        push @results, $self->result($tag);
     }
     return wantarray ? @results : \@results;
 }
 
 
-=item $t->data($event), $t->data;
+=item $t->data($tag), $t->data;
 
 These methods are useful if you want to recover the full internal timing
 data to roll your own reports.
 
-If called with an $event, returns the raw timing data for that $event as
+If called with a $tag, returns the raw timing data for that $tag as
 an array (or a reference to an array if called in scalar context). This is
 useful for feeding to something like the Statistics::Descriptive package.
 
 If called with no arguments, returns the raw timing data as a hash keyed
-on event tags, where the values of the hash are lists of timings for that
-event. In scalar context, it returns a reference to that hash. As with
+on tags, where the values of the hash are lists of timings for that
+code. In scalar context, it returns a reference to that hash. As with
 C<results()>, the data is internally represented as an array so you can
-recover the original event order by assigning to an array instead of a hash.
+recover the original tag order by assigning to an array instead of a hash.
 
 =cut
 
 sub data {
     my $self = shift;
-    my $event = shift;
+    my $tag = shift;
     my @results;
-    if($event) {
-        if(exists $self->[ELAPSED]->{$event}) {
-            @results = @{$self->[ELAPSED]->{$event}};
+    if($tag) {
+        if(exists $self->[ELAPSED]->{$tag}) {
+            @results = @{$self->[ELAPSED]->{$tag}};
         } else {
             @results = ();
         }
     } else {
         @results = map { ( $_ => $self->[ELAPSED]->{$_} || [] ) }
-                          @{$self->[EVENTS]};
+                          @{$self->[TAGS]};
     }
     return wantarray ? @results : \@results;
 }
